CODE_REVIEW_SYSTEM_PROMPT = """
As a senior software developer reviewing code submissions, provide thorough, constructive feedback and suggestions for improvements. Consider best practices, error handling, performance, readability, and maintainability. Offer objective and respectful reviews that help developers enhance their skills and code quality. Use your expertise to provide comprehensive feedback without asking clarifying questions.
"""

CODE_REVIEW_PROMPT = """
As an experienced software engineer, provide a concise, actionable code review for the given pull request. Generate a JSON object with the following structure:
{{
  "code_quality_percentage": <0_TO_100>,
  "review": [
    {{
      "topic": "<SECTION_TOPIC>",
      "comment": "<CONCISE_ISSUE_DESCRIPTION>",
      "confidence": "critical|important|moderate|low|trivial",
      "reason": "<ISSUE_REASONING>",
      "solution": "<HIGH_LEVEL_SOLUTION>",
      "actual_code": "<PEICE_OF_CODE_WHICH_HAS_ISSUES>",
      "fixed_code": "<CORRECTED_CODE>",
      "file_name": "<FULL_FILE_PATH>",
      "start_line": <START_LINE_NUMBER>,
      "end_line": <END_LINE_NUMBER>,
      "side": "LEFT|RIGHT",
      "sentiment": "positive|negative|neutral",
      "severity_level": <1_TO_10>
    }}
  ]
}}

## Guidelines:
- Provide specific feedback with file paths and line numbers
- Use markdown for code snippets. Make sure all code is following the original indentations.
- Merge duplicate feedback
- Examine: syntax/logic errors, resource leaks, race conditions, security vulnerabilities
- If no issues found: {{"review": []}}

## Patch Data Format:
- First column: Original file line numbers
- Second column: New file line numbers (spaces for removed lines)
- Third column: Change type
  '-1:[-]': Line removed
  '+1:[+]': Line added
  '0:[.]': Unchanged line
- Remaining columns: Code content

Example:

1    -    -1:[-] def old_function(x):
2         +1:[+] def new_function(x, y):
3    3     0:[.]     result = x * 2
4         +1:[+]     result += y
4    5     0:[.]     return result

## Review Focus:
1. Removals (-1:[-]): Identify if removal causes problems in remaining code.
2. Additions (+1:[+]): Provide detailed feedback and suggest improvements.
3. Consider impact of changes on overall code structure and functionality.
4. Note unchanged lines (0:[.]) for context.

## Field Guidelines:
- "fixed_code": Corrected code for additions only, between start_line and end_line.
- "start_line" and "end_line": Actual line numbers in the new file.
- "severity_level": 1 (least severe) to 10 (most critical).

## PATCH DATA:
```{CODE_DIFF}```
"""

FILE_CODE_REVIEW_PROMPT = """
As an experienced software engineer, provide a concise, actionable code review for the given pull request. Generate a JSON object with the following structure:
{{
  "code_quality_percentage": <0_TO_100>,
  "review": [
    {{
      "topic": "<SECTION_TOPIC>",
      "comment": "<CONCISE_ISSUE_DESCRIPTION>",
      "confidence": "critical|important|moderate|low|trivial",
      "reason": "<ISSUE_REASONING>",
      "solution": "<HIGH_LEVEL_SOLUTION>",
      "actual_code": "<PEICE_OF_CODE_WHICH_HAS_ISSUES>",
      "fixed_code": "<CORRECTED_CODE>",
      "file_name": "<FULL_FILE_PATH>",
      "start_line": <START_LINE_NUMBER>,
      "end_line": <END_LINE_NUMBER>,
      "side": "LEFT|RIGHT",
      "sentiment": "positive|negative|neutral",
      "severity_level": <1_TO_10>
    }}
  ]
}}

## Guidelines:
- Provide specific feedback with file paths and line numbers
- Use markdown for code snippets. Make sure all code is following the original indentations.
- Merge duplicate feedback
- Examine: syntax/logic errors, resource leaks, race conditions, security vulnerabilities
- If no issues found: {{"review": []}}

## Patch Data Format:
- First column: Original file line numbers
- Second column: New file line numbers (spaces for removed lines)
- Third column: Change type
  '-1:[-]': Line removed
  '+1:[+]': Line added
  '0:[.]': Unchanged line
- Remaining columns: Code content

Example:

1    -    -1:[-] def old_function(x):
2         +1:[+] def new_function(x, y):
3    3     0:[.]     result = x * 2
4         +1:[+]     result += y
4    5     0:[.]     return result

## Review Focus:
1. Removals (-1:[-]): Identify if removal causes problems in remaining code.
2. Additions (+1:[+]): Provide detailed feedback and suggest improvements.
3. Consider impact of changes on overall code structure and functionality.
4. Note unchanged lines (0:[.]) for context.

## Field Guidelines:
- "fixed_code": Corrected code for additions only, between start_line and end_line.
- "start_line" and "end_line": Actual line numbers in the new file.
- "severity_level": 1 (least severe) to 10 (most critical).

## File PATCH Data:
```{FILE_PATCH}```
"""


PR_REVIEW_EVALUATION_PROMPT = """
As an experienced software engineer, evaluate and improve your previous code review for the given pull request. Analyze your initial feedback, identify any missed issues or inaccuracies, and provide a comprehensive, corrected review.

Generate a JSON object with the following structure:
{{
  "code_quality_percentage": <0_TO_100>,
  "review": [
    {{
      "topic": "<SECTION_TOPIC>",
      "comment": "<CONCISE_ISSUE_DESCRIPTION>",
      "confidence": "critical|important|moderate|low|trivial",
      "reason": "<ISSUE_REASONING>",
      "solution": "<HIGH_LEVEL_SOLUTION>",
      "actual_code": "<PEICE_OF_CODE_WHICH_HAS_ISSUES>",
      "fixed_code": "<CORRECTED_CODE>",
      "file_name": "<FULL_FILE_PATH>",
      "start_line": <START_LINE_NUMBER>,
      "end_line": <END_LINE_NUMBER>,
      "side": "LEFT|RIGHT",
      "sentiment": "positive|negative|neutral",
      "severity_level": <1_TO_10>
    }}
  ]
}}

## Guidelines:
- Thoroughly review your previous output and the original code changes
- Identify any missed issues, inaccuracies, or areas for improvement
- Provide specific feedback with file paths and line numbers
- Use markdown for code snippets. Make sure all code is following the original indentations.
- If no issues found or no changes needed: {{"review": []}}

## Patch Data Format:
- First column: Original file line numbers
- Second column: New file line numbers (spaces for removed lines)
- Third column: Change type
  '-1:[-]': Line removed
  '+1:[+]': Line added
  '0:[.]': Unchanged line
- Remaining columns: Code content

## Review Focus:
1. Removals (-1:[-]): Ensure you've correctly identified if their removal causes any problems.
2. Additions (+1:[+]): Verify your feedback is detailed and suggestions for improvements are appropriate.
3. Re-evaluate the impact of changes on overall code structure and functionality.
4. Check if you've missed any important issues or provided any incorrect advice.

## Field Guidelines:
- "topic": Briefly describe the issue or area of improvement.
- "comment": Provide a concise description of the issue.
- "confidence": Use the appropriate level based on the severity and certainty of the issue.
- "reason": Explain why this issue is important or needs attention.
- "solution": Provide a high-level solution to the identified issue.
- "fixed_code": Provide corrected code only for additions, ensuring changes are between start_line and end_line.
- "start_line" and "end_line": Actual line numbers in the new file where the change begins and ends.
- "side": Use "LEFT" for deleted lines (-1:[-]), "RIGHT" for added lines (+1:[+]).
- "file_name": Include the full file path for precise issue location.
- "sentiment": Indicate whether the comment is "positive", "negative", or "neutral".
- "severity_level": Score from 1 (least severe) to 10 (most critical).

ORIGINAL PROMPT:
{ACTUAL_PROMPT}

PREVIOUS OUTPUT:
{LLM_OUTPUT}

Based on this evaluation, provide a corrected and improved code review that addresses any oversights or inaccuracies in your initial review.
"""
